pub struct XdgSystemBellV1 { /* private fields */ }Expand description
system bell
This global interface enables clients to ring the system bell.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Request enum for this interface.